==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/PagedDataSource.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LocalDataSource } from "./LocalDataSource";
import { DataSourceExecutionContext } from "./DataSourceExecutionContext";
import { markType } from "./type";
/**
 * @hidden
 */
var PagedDataSource = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PagedDataSource, _super);
    function PagedDataSource(a) {
        var _this = _super.call(this) || this;
        _this.d6 = null;
        _this.d7 = false;
        _this.actualDataProvider = a;
        _this.actualDataProvider.executionContext = new DataSourceExecutionContext();
        return _this;
    }
    PagedDataSource.prototype.isPlaceholderItem = function (a) {
        return !this.d7;
    };
    PagedDataSource.prototype.getItemPropertyAtIndex = function (a, b) {
        if (this.d6.isVirtual) {
            if (this.getRowType(a) != 0) {
                return _super.prototype.getItemPropertyAtIndex.call(this, a, b);
            }
            else {
                var c = this.getItemAtIndex(a);
                if (c == null) {
                    return null;
                }
                return this.getItemProperty(c, b);
            }
        }
        return _super.prototype.getItemPropertyAtIndex.call(this, a, b);
    };
    PagedDataSource.prototype.getItemProperty = function (a, b) {
        if (a == null) {
            return null;
        }
        if (this.d6.isVirtual) {
            return this.d6.getItemProperty(a, b);
        }
        return _super.prototype.getItemProperty.call(this, a, b);
    };
    PagedDataSource.prototype.setSchema = function (a) {
        if (this.actualBaseDataProvider != null) {
            this.actualBaseDataProvider.al(a);
            this.queueAutoRefresh();
        }
    };
    PagedDataSource.$t = markType(PagedDataSource, 'PagedDataSource', LocalDataSource.$);
    return PagedDataSource;
}(LocalDataSource));
export { PagedDataSource };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PagedDataSource.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { LocalDataSource } from "./LocalDataSource";
import { DataSourceExecutionContext } from "./DataSourceExecutionContext";
import { markType } from "./type";
/**
 * @hidden
 */
var PagedDataSource = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PagedDataSource, _super);
    function PagedDataSource(a) {
        var _this = _super.call(this) || this;
        _this.d6 = null;
        _this.d7 = false;
        _this.actualDataProvider = a;
        _this.actualDataProvider.executionContext = new DataSourceExecutionContext();
        return _this;
    }
    PagedDataSource.prototype.isPlaceholderItem = function (a) {
        return !this.d7;
    };
    PagedDataSource.prototype.getItemPropertyAtIndex = function (a, b) {
        if (this.d6.isVirtual) {
            if (this.getRowType(a) != 0) {
                return _super.prototype.getItemPropertyAtIndex.call(this, a, b);
            }
            else {
                var c = this.getItemAtIndex(a);
                if (c == null) {
                    return null;
                }
                return this.getItemProperty(c, b);
            }
        }
        return _super.prototype.getItemPropertyAtIndex.call(this, a, b);
    };
    PagedDataSource.prototype.getItemProperty = function (a, b) {
        if (a == null) {
            return null;
        }
        if (this.d6.isVirtual) {
            return this.d6.getItemProperty(a, b);
        }
        return _super.prototype.getItemProperty.call(this, a, b);
    };
    PagedDataSource.prototype.setSchema = function (a) {
        if (this.actualBaseDataProvider != null) {
            this.actualBaseDataProvider.ar(a);
            this.queueAutoRefresh();
        }
    };
    PagedDataSource.$t = markType(PagedDataSource, 'PagedDataSource', LocalDataSource.$);
    return PagedDataSource;
}(LocalDataSource));
export { PagedDataSource };
